@@ -176,8 +176,9 @@ def set_idemailstatus_target_column(df):
         df = df[~df['IDEmailStatus'].isin([3, 5, 7, 32])]
         df.loc[df['IDEmailStatus'] != 14, 'IDEmailStatus'] = 0
         df.loc[df['IDEmailStatus'] == 14, 'IDEmailStatus'] = 1
-        status_col = df.pop( 'IDEmailStatus')
-        df.insert(0, status_col, 'IDEmailStatus')
+        status_col = df['IDEmailStatus']
+        df.drop( labels=['IDEmailStatus'], axis=1, inplace=True )
+        df.insert(loc=0, value=status_col, column= 'IDEmailStatus')
     else:
         logger.error('No IDEmailSTatus column found')
         raise Exception('No IDEmailStatus column found!!!!!')
@@ -189,8 +190,9 @@ def set_bv_target_column(df):
         logger.info('Setting BV status target ')
         df = df[df.BV.notna()]
         df['BV']=df['BV'].astype('float32')
-        bv_col = df.pop( 'BV')
-        df.insert(0, bv_col, 'BV')
+        bv_col = df['BV']
+        df.drop( labels=['BV'], axis=1, inplace=True )
+        df.insert( loc=0, value=bv_col, column='BV' )
     else:
         logger.error('No BV column found')
         raise Exception('No BV column found!!!!!')
